@@ -41,7 +41,7 @@ from rich.theme import Theme
 import darwin.datatypes as dt
 from darwin.datatypes import PathLike
 from darwin.exceptions import IncompatibleOptions, RequestEntitySizeExceeded
-from darwin.utils import secure_continue_request
+from darwin.utils import flatten_list, secure_continue_request
 from darwin.version import __version__
 
 # Classes missing import support on backend side
@@ -351,7 +351,8 @@ def import_annotations(
     if not maybe_parsed_files:
         raise ValueError("Not able to parse any files.")
 
-    parsed_files = list(maybe_parsed_files)
+    parsed_files: List[AnnotationFile] = flatten_list(list(maybe_parsed_files))
+
     filenames: List[str] = [parsed_file.filename for parsed_file in parsed_files if parsed_file is not None]
 
     console.print("Fetching remote file list...", style="info")
@@ -478,7 +479,7 @@ def import_annotations(
 
                 image_id, default_slot_name = remote_files[parsed_file.full_path]
 
-                _import_annotations(
+                errors, succes = _import_annotations(
                     dataset.client,
                     image_id,
                     remote_classes,
@@ -492,6 +493,11 @@ def import_annotations(
                     import_reviewers,
                 )
 
+                if errors:
+                    console.print(f"Errors importing {parsed_file.filename}", style="error")
+                    for error in errors:
+                        console.print(f"\t{error}", style="error")
+
 
 def _get_multi_cpu_settings(cpu_limit: Optional[int], cpu_count: int, use_multi_cpu: bool) -> Tuple[int, bool]:
     if cpu_limit == 1 or cpu_count == 1 or not use_multi_cpu:
@@ -578,7 +584,7 @@ def _handle_annotators(annotation: dt.Annotation, import_annotators: bool) -> Li
     return []
 
 
-def _handle_video_annotations(
+def _get_annotation_data(
     annotation: dt.AnnotationLike,
     annotation_class_id: str,
     attributes: dt.DictFreeForm,
@@ -594,6 +600,8 @@ def _handle_video_annotations(
         )
     else:
         data = {annotation_class.annotation_type: annotation.data}
+        data = _handle_complex_polygon(annotation, data)
+        data = _handle_subs(annotation, data, annotation_class_id, attributes)
 
     return data
 
@@ -621,16 +629,17 @@ def _import_annotations(
     delete_for_empty: bool,  # TODO: This is unused, should it be?
     import_annotators: bool,
     import_reviewers: bool,
-) -> None:
+) -> Tuple[dt.ErrorList, dt.Success]:
+    errors: dt.ErrorList = []
+    success: dt.Success = dt.Success.SUCCESS
+
     serialized_annotations = []
     for annotation in annotations:
         annotation_class = annotation.annotation_class
         annotation_type = annotation_class.annotation_internal_type or annotation_class.annotation_type
         annotation_class_id: str = remote_classes[annotation_type][annotation_class.name]
 
-        data = _handle_video_annotations(annotation, annotation_class_id, attributes, annotation.data)
-        data = _handle_complex_polygon(annotation, data)
-        data = _handle_subs(annotation, data, annotation_class_id, attributes)
+        data = _get_annotation_data(annotation, annotation_class_id, attributes, annotation.data)
 
         actors: List[dt.DictFreeForm] = []
         actors.extend(_handle_annotators(annotation, import_annotators))
@@ -653,7 +662,13 @@ def _import_annotations(
     payload: dt.DictFreeForm = {"annotations": serialized_annotations}
     payload["overwrite"] = _get_overwrite_value(append)
 
-    dataset.import_annotation(id, payload=payload)
+    try:
+        dataset.import_annotation(id, payload=payload)
+    except Exception as e:
+        errors.append(e)
+        success = dt.Success.FAILURE
+
+    return errors, success
 
 
 def _console_theme() -> Theme:
